@@ -1,7 +1,7 @@
 #!/bin/sh
 
 ###############################################################################
-# UExtract v3.41 by JakeSFR (a.k.a. SFR)'2013-2020                            #
+# UExtract v4.6 by JakeSFR (a.k.a. SFR)'2013-2021                             #
 # GNU GPL v2 applies                                                          #
 # Thanks to Pemasu for helping me with making this script Woof-friendly       #
 ###############################################################################
@@ -21,16 +21,16 @@ if [ "$(pwd)" = "/" ]; then
 	for i in "$LOC1" "$LOC2" "$LOC3" "$LOC3" "$LOC4"; do
 		[ -d "$i" ] && { RC_PATH="$i"; break; }
 	done
-	DOTdesktop_PATH="/usr/share/applications/UExtract.desktop"
+	DOTdesktop_PATH="/usr/local/apps/UExtract/UExtract.desktop"
 else	# Woof/Fatdog build system
 	for i in ".$LOC1" ".$LOC2" ".$LOC3" ".$LOC4"; do
 		[ -d "$i" ] && { RC_PATH="$i"; break; }
 	done
-	DOTdesktop_PATH="./usr/share/applications/UExtract.desktop"
+	DOTdesktop_PATH="./usr/local/apps/UExtract/UExtract.desktop"
 fi
 
 
-# BTW, Mime-Types are kept inside UExtract.desktop file
+# Mime-Types are kept inside UExtract.desktop file
 if [ -d "$RC_PATH" ]; then
 	for i in $(grep '^MimeType=' "$DOTdesktop_PATH" | cut -f2- -d '=' | tr ';' '\n' | tr '/' '_' | head -n -1); do
 		[ ! -d "${RC_PATH}/.${i}" ] && mkdir "${RC_PATH}/.${i}" 
