@@ -1,7 +1,7 @@
 #!/bin/sh
 
 ###############################################################################
-# UExtract v3.41 by JakeSFR (a.k.a. SFR)'2013-2020                            #
+# UExtract v4.6 by JakeSFR (a.k.a. SFR)'2013-2021                             #
 # GNU GPL v2 applies                                                          #
 ###############################################################################
 
@@ -28,7 +28,8 @@ done
 # -----------------------------------------------------------------------------
 
 # Remove icon from ROX pinboard and Desktop folder
-[ -e "$HOME/Choices/ROX-Filer/PuppyPin" ] &&
+[ -e "$HOME/Choices/ROX-Filer/PuppyPin" ] ||
+[ -e "$HOME/.config/rox.sourceforge.net/ROX-Filer/PuppyPin" ] &&
 rox --RPC << EOF
 <?xml version="1.0"?>
 <env:Envelope xmlns:env="http://www.w3.org/2001/12/soap-envelope">
